@@ -18,9 +18,15 @@ _eet_str_direct_free(const char *str)
    (void) str;
 }
 
+static void
+_eet_eina_hash_foreach(void *hash, Eina_Hash_Foreach cb, void *fdata)
+{
+   if (hash) eina_hash_foreach(hash, cb, fdata);
+}
+
 /* Internal wrapper for eina_hash */
-Eina_Hash*
-eet_eina_hash_add(Eina_Hash *hash, const char *key, const void *data)
+static Eina_Hash*
+_eet_eina_hash_add(Eina_Hash *hash, const char *key, const void *data)
 {
    if (!hash) hash = eina_hash_string_superfast_new(NULL);
    if (!hash) return NULL;
@@ -29,6 +35,12 @@ eet_eina_hash_add(Eina_Hash *hash, const char *key, const void *data)
    return hash;
 }
 
+static void
+_eet_eina_hash_free(Eina_Hash *hash)
+{
+   if (hash) eina_hash_free(hash);
+}
+
 void
 eet_test_setup_eddc(Eet_Data_Descriptor_Class *eddc)
 {
@@ -41,9 +53,9 @@ eet_test_setup_eddc(Eet_Data_Descriptor_Class *eddc)
    eddc->func.list_append = (void*) eina_list_append;
    eddc->func.list_data = (void*) eina_list_data_get;
    eddc->func.list_free = (void*) eina_list_free;
-   eddc->func.hash_foreach = (void*) eina_hash_foreach;
-   eddc->func.hash_add = (void*) eet_eina_hash_add;
-   eddc->func.hash_free = (void*) eina_hash_free;
+   eddc->func.hash_foreach = (void*) _eet_eina_hash_foreach;
+   eddc->func.hash_add = (void*) _eet_eina_hash_add;
+   eddc->func.hash_free = (void*) _eet_eina_hash_free;
    eddc->func.str_direct_alloc = (void*) _eet_str_direct_alloc;
    eddc->func.str_direct_free = (void*) _eet_str_direct_free;
 }
